==> WPyrogram-2.0.107-py3-none-any.whl: pyrogram/raw/functions/stories/__init__.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from .can_send_story import CanSendStory
from .send_story import SendStory
from .edit_story import EditStory
from .delete_stories import DeleteStories
from .toggle_pinned import TogglePinned
from .get_all_stories import GetAllStories
from .get_user_stories import GetUserStories
from .get_pinned_stories import GetPinnedStories
from .get_stories_archive import GetStoriesArchive
from .get_stories_by_id import GetStoriesByID
from .toggle_all_stories_hidden import ToggleAllStoriesHidden
from .get_all_read_user_stories import GetAllReadUserStories
from .read_stories import ReadStories
from .increment_story_views import IncrementStoryViews
from .get_story_views_list import GetStoryViewsList
from .get_stories_views import GetStoriesViews
from .export_story_link import ExportStoryLink
from .report import Report
from .activate_stealth_mode import ActivateStealthMode
from .send_reaction import SendReaction

==> WPyrogram-2.0.126-py3-none-any.whl: pyrogram/raw/functions/stories/__init__.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from .can_send_story import CanSendStory
from .send_story import SendStory
from .edit_story import EditStory
from .delete_stories import DeleteStories
from .toggle_pinned import TogglePinned
from .get_all_stories import GetAllStories
from .get_pinned_stories import GetPinnedStories
from .get_stories_archive import GetStoriesArchive
from .get_stories_by_id import GetStoriesByID
from .toggle_all_stories_hidden import ToggleAllStoriesHidden
from .read_stories import ReadStories
from .increment_story_views import IncrementStoryViews
from .get_story_views_list import GetStoryViewsList
from .get_stories_views import GetStoriesViews
from .export_story_link import ExportStoryLink
from .report import Report
from .activate_stealth_mode import ActivateStealthMode
from .send_reaction import SendReaction
from .get_peer_stories import GetPeerStories
from .get_all_read_peer_stories import GetAllReadPeerStories
from .get_peer_max_i_ds import GetPeerMaxIDs
from .get_chats_to_send import GetChatsToSend
from .toggle_peer_stories_hidden import TogglePeerStoriesHidden
from .get_boosts_status import GetBoostsStatus
from .get_boosters_list import GetBoostersList
from .can_apply_boost import CanApplyBoost
from .apply_boost import ApplyBoost
